////////////////////////////////////////////////
// Functions for the customize dialog
////////////////////////////////////////////////

//
// Reload list items into current listbox
//
function ReloadCurrentList() {
	var labels = LoadFromPrefs();
	var listbox = document.getElementById("firesizer-customize-currentlist");
	// Clear list first
	while( listbox.getRowCount() != 0 ) { listbox.removeItemAt(0); }
	// Add the current items
	for( var i=0; i<labels.length; i++ ) {
		listbox.appendItem(labels[i], labels[i]);
	}
}


//
// Remove a dimension from the list
//
function RemoveDimension(dimstr) {
	var dimensions = LoadFromPrefs();
	var newdimensions = new Array();
	for( var i=0; i<dimensions.length; i++ ) {
		if( dimensions[i] != dimstr ) {
			newdimensions[newdimensions.length++] = dimensions[i];
		}
	}
	SaveToPrefs(newdimensions);
}


//
// Load strings from localization bundle
//	Uses global variable "localeStr"
function LoadLocaleStrings() {
	var bundleMgr = Components.classes["@mozilla.org/intl/stringbundle;1"].
		getService(Components.interfaces.nsIStringBundleService);
	var customizeStrBundle = bundleMgr.createBundle("chrome://firesizer/locale/customize.properties");
	localeStr["SelectDelete"] = customizeStrBundle.GetStringFromName("firesizerSelectItemToDelete");
	localeStr["EnterSize"]    = customizeStrBundle.GetStringFromName("firesizerWidthHeight");
}


/////////////////////////////////////////////
// Event handlers

//
// Handle delete button press
//
function FiresizerCustomizeDelete() {
	var listbox = document.getElementById("firesizer-customize-currentlist");
	if( listbox.selectedItem == null ) {
		alert(localeStr["SelectDelete"]);
	} else {
		RemoveDimension(listbox.selectedItem.label);
		ReloadCurrentList();
	}
}


//
// Handle keypresses we want in the listbox
//
function FiresizerCustomizeListKeypress(evt) {
	if( evt.keyCode == 46 ) {
		FiresizerCustomizeDelete();
		return false;
	} else {
		return true;
	}
}


//
// Handle add button press
//
function FiresizerCustomizeAdd() {
	var width  = document.getElementById("firesizer-customize-addwidth");
	var height = document.getElementById("firesizer-customize-addheight");

	// Strip non-numeric values
	width.value.replace(/\D+/g, '');
	height.value.replace(/\D+/g, '');

	// Make sure it's not empty
	if( isEmpty(width.value) || isEmpty(height.value) ) {
		alert(localeStr["EnterSize"]);
	} else {
		// Add new item to the list
		var listbox = document.getElementById("firesizer-customize-currentlist");
		AddDimension(width.value, height.value);
		ReloadCurrentList();
		// Clear out text boxes for next addition
		width.value = "";
		height.value = "";
	}
}


//
// Restrict text field to numeric only
//
function FiresizerCustomizeNumberOnly(evt) {
	// allow non-char keys to pass (Esc, Tab, Del, etc...)
	if( evt.charCode == 0 ) {
		return true; 
	}
	// Only allow 0-9
	if( (String.fromCharCode(evt.charCode) >= "0" && String.fromCharCode(evt.charCode) <= "9") ) {
		return true;
	} else {
		return false;
	}
}


//
// Handle the onLoad event
//
function FiresizerCustomizeDoOnLoad() {
	LoadLocaleStrings();
	ReloadCurrentList();
}


/////////////////////////////////////////////
// Initialize after the page is loaded

var localeStr = new Array();
window.addEventListener("load", FiresizerCustomizeDoOnLoad, false);


