//////////////////////////////////////////////////////
// Main firesizer script
//     Handles functions related to the statusbar panel
//
// Brian Mathis <bmathis-firesizer
// ------------                   @directedge.us>
//
// Heavily inspired by Galoca's "Yet Another Window Resizer"
// which is available: https://addons.mozilla.org/en-US/firefox/addon/2498
//
//////////////////////////////////////////////////////

//
// Open customize dialog
//
function FiresizerCustomize() {
	window.openDialog("chrome://firesizer/content/customize.xul", 
		null, "chrome,centerscreen,dependent");
}


//
// Save the current size to prefs
//
function FiresizerSaveCurrent() {
	var width  = window.outerWidth  + '';
	var height = window.outerHeight + '';
	AddDimension(width, height);
}


//
// Update the status bar panel with the current window size
//
function FiresizerUpdateStatus() {
	var width  = window.outerWidth  + '';
	var height = window.outerHeight + '';
	document.getElementById("firesizer-statuspanel").label = width + 'x' + height;
}


//
// Change the size of the window
//
function FiresizerResizeWindow(width, height) {
	if( isNaN(width) || isNaN(height) ) {
		alert(localeStr["InvalidDimensions"] + width + "x" + height);
	} else {
		window.outerWidth  = width;
		window.outerHeight = height;
	}
}


//
// Show menu on right-click
//
function FiresizerShowMenu() {
	var labels = LoadFromPrefs();
	var statusmenu = document.getElementById("firesizer-statuspanel-menu");

	// Clear the menu
	while( statusmenu.childNodes.length > 0 ) {
		statusmenu.removeChild( statusmenu.childNodes[0] );
	}

	// Add the dimension menu items
	for( var i=0; i < labels.length; i++ ) {
		// Split out the width and height
		var wxh = labels[i].split("x");
		var width  = Number(wxh[0]);
		var height = Number(wxh[1]);

		// Create the new menu item
		var menuitem = document.createElement("menuitem");
		menuitem.setAttribute("label", labels[i]);
		menuitem.setAttribute("id",    labels[i]);
		menuitem.setAttribute("value", "firesizer-menuitem");
		menuitem.setAttribute("oncommand", "FiresizerResizeWindow(" + width + "," + height + ")");
		statusmenu.appendChild(menuitem);
	}

	// Add separator
	var separator = document.createElement("menuseparator");
	separator.setAttribute("id", "firesizer-statuspanel-separator");
	statusmenu.appendChild(separator);
	
	// Add "customize" item
	var customize = document.createElement("menuitem");
	customize.setAttribute("id", "firesizer-statuspanel-customize");
	customize.setAttribute("label", localeStr["Customize"]);
	customize.setAttribute("accesskey", localeStr["CustomizeKey"]);
	customize.setAttribute("oncommand", "FiresizerCustomize()");
	statusmenu.appendChild(customize);

	// Add "Save current" item
	var customize = document.createElement("menuitem");
	customize.setAttribute("id", "firesizer-statuspanel-savecurrent");
	customize.setAttribute("label", localeStr["SaveCurrent"]);
	customize.setAttribute("accesskey", localeStr["SaveCurrentKey"]);
	customize.setAttribute("oncommand", "FiresizerSaveCurrent()");
	statusmenu.appendChild(customize);
}


//
// Load strings from localization bundle
//	Uses global variable "localeStr"
function FiresizerLoadLocaleStrings() {
	var bundleMgr = Components.classes["@mozilla.org/intl/stringbundle;1"].
		getService(Components.interfaces.nsIStringBundleService);
	var firesizerStrBundle = bundleMgr.createBundle("chrome://firesizer/locale/firesizer.properties");
	localeStr["InvalidDimensions"]	= firesizerStrBundle.GetStringFromName("firesizerInvalidDimensions");
	localeStr["Customize"]		= firesizerStrBundle.GetStringFromName("firesizerCustomize");
	localeStr["CustomizeKey"]	= firesizerStrBundle.GetStringFromName("firesizerCustomizeKey");
	localeStr["SaveCurrent"]	= firesizerStrBundle.GetStringFromName("firesizerSaveCurrent");
	localeStr["SaveCurrentKey"]	= firesizerStrBundle.GetStringFromName("firesizerSaveCurrentKey");
}


//
// Do initialization onload
//
function FiresizerDoOnLoad() {
	FiresizerLoadLocaleStrings();
	FiresizerUpdateStatus();		// Update statusbar with current size
}


//
// Add event listeners
//
window.addEventListener("load",   FiresizerDoOnLoad, false);
window.addEventListener("resize", FiresizerUpdateStatus, false);

// global to hold locale strings
var localeStr = new Array();

